@@ -3,11 +3,11 @@
 
 
 #' Seasonal adjustment
-#' 
+#'
 #' Returns seasonally adjusted data constructed by removing the seasonal
 #' component.
-#' 
-#' 
+#'
+#'
 #' @param object Object created by \code{\link[stats]{decompose}},
 #' \code{\link[stats]{stl}} or \code{\link{tbats}}.
 #' @param ... Other arguments not currently used.
@@ -19,31 +19,35 @@
 #' @examples
 #' plot(AirPassengers)
 #' lines(seasadj(decompose(AirPassengers,"multiplicative")),col=4)
-#' 
+#'
 #' @export
-seasadj <- function(object,...) UseMethod("seasadj")
+seasadj <- function(object, ...) UseMethod("seasadj")
 
 #' @rdname seasadj
 #' @export
-seasadj.stl <- function(object, ...)
-{
-   return(trendcycle(object) + remainder(object))
+seasadj.stl <- function(object, ...) {
+  return(trendcycle(object) + remainder(object))
 }
 
 #' @rdname seasadj
 #' @export
-seasadj.decomposed.ts <- function(object, ...)
-{
-  if(object$type=="additive")
+seasadj.mstl <- function(object, ...) {
+  return(trendcycle(object) + remainder(object))
+}
+
+#' @rdname seasadj
+#' @export
+seasadj.decomposed.ts <- function(object, ...) {
+  if (object$type == "additive") {
     return(object$x - object$seasonal)
-  else
+  } else {
     return(object$x / object$seasonal)
+  }
 }
 
 #' @rdname seasadj
 #' @export
-seasadj.tbats <- function(object, ...)
-{
+seasadj.tbats <- function(object, ...) {
   return(object$y - seasonal(object))
   # comp <- tbats.components(object)
   # scols <- grep("season",colnames(comp))
@@ -56,7 +60,6 @@ seasadj.tbats <- function(object, ...)
 
 #' @rdname seasadj
 #' @export
-seasadj.seas <- function(object, ...)
-{
+seasadj.seas <- function(object, ...) {
   return(seasextract_w_na_action(object, "final"))
 }
