@@ -3,8 +3,6 @@
 
 # Author: RJH
 
-
-
 #' Theta method forecast
 #'
 #' Returns forecasts and prediction intervals for a theta method forecast.
@@ -81,7 +79,7 @@ thetaf <- function(y, h=ifelse(frequency(y) > 1, 2 * frequency(y), 10),
   n <- length(x)
   x <- as.ts(x)
   m <- frequency(x)
-  if (m > 1 && !is.constant(x)) {
+  if (m > 1 && !is.constant(x) && n > m) {
     r <- as.numeric(acf(x, lag.max = m, plot = FALSE)$acf)[-1]
     stat <- sqrt((1 + 2 * sum(r[-m] ^ 2)) / n)
     seasonal <- (abs(r[m]) / stat > qnorm(0.95))
@@ -109,7 +107,9 @@ thetaf <- function(y, h=ifelse(frequency(y) > 1, 2 * frequency(y), 10),
   # Reseasonalize
   if (seasonal) {
     fcast$mean <- fcast$mean * rep(tail(decomp$seasonal, m), trunc(1 + h / m))[1:h]
+    fcast$fitted <- fcast$fitted * decomp$seasonal
   }
+  fcast$residuals <- origx-fcast$fitted
 
   # Find prediction intervals
   fcast.se <- sqrt(fcast$model$sigma) * sqrt((0:(h - 1)) * alpha ^ 2 + 1)
